import React, { useState, useRef } from 'react';
import RecordRTC from 'recordrtc';
import { transcribeAudio } from '../services/whisperApi';
import { editHTMLWithOpenRouter } from '../services/openrouterApi';
import './RecordingSection.css';

const RecordingSection = ({ selectedSection, onUpdateHtml }) => {
  const [isRecording, setIsRecording] = useState(false);
  const [editType, setEditType] = useState('agentx');
  const [error, setError] = useState('');
  const recorderRef = useRef(null);

  const startRecording = async () => {
    try {
      const stream = await navigator.mediaDevices.getUserMedia({ audio: true });
      recorderRef.current = new RecordRTC(stream, {
        type: 'audio',
        mimeType: 'audio/webm',
        recorderType: RecordRTC.StereoAudioRecorder
      });
      
      recorderRef.current.startRecording();
      setIsRecording(true);
      setError('');
    } catch (err) {
      console.error('Recording error:', err);
      setError('Failed to start recording: ' + err.message);
    }
  };

  const stopRecording = () => {
    return new Promise((resolve) => {
      recorderRef.current.stopRecording(() => {
        const blob = recorderRef.current.getBlob();
        resolve(blob);
      });
    });
  };

  const handleRecord = async () => {
    if (!selectedSection) {
      setError('Please select a section to edit first');
      return;
    }

    if (isRecording) {
      try {
        setIsRecording(false);
        const audioBlob = await stopRecording();
        
        // Transcribe audio with Whisper
        const transcription = await transcribeAudio(audioBlob);
        console.log('Transcription:', transcription);

        // Edit HTML with OpenRouter
        const updatedHtml = await editHTMLWithOpenRouter(selectedSection.html, transcription);
        console.log('Updated HTML:', updatedHtml);

        // Update parent component
        onUpdateHtml(updatedHtml, selectedSection.id);
      } catch (err) {
        console.error('Processing error:', err);
        setError('Failed to process recording: ' + err.message);
      }
    } else {
      startRecording();
    }
  };

  return (
    <div className="recording-section">
      <h3>Selected Section: {selectedSection?.id || 'None'}</h3>

      <div className="edit-types">
        <button 
          className={`edit-type-btn ${editType === 'agentx' ? 'active' : ''}`}
          onClick={() => setEditType('agentx')}
        >
          Agent X
        </button>
        {['image', 'remix', 'html', 'text', 'web'].map(type => (
          <button 
            key={type}
            className="edit-type-btn disabled"
            disabled
          >
            {type}
          </button>
        ))}
      </div>

      <button 
        className={`record-btn ${isRecording ? 'recording' : ''}`}
        onClick={handleRecord}
      >
        {isRecording ? 'Stop Recording' : 'Start Recording'}
      </button>

      {error && <p className="error-message">{error}</p>}
    </div>
  );
};

export default RecordingSection;

