import React, { useState, useEffect } from 'react';
import { useLocation, useNavigate } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { doc, getDoc } from 'firebase/firestore';
import PreviewFrame from '../components/PreviewFrame';
import RecordingSection from '../components/RecordingSection';
import SessionControls from '../components/SessionControls';
import './CurrentPage.css';

const CurrentPage = () => {
  const location = useLocation();
  const navigate = useNavigate();
  const [sessionData, setSessionData] = useState(null);
  const [selectedSection, setSelectedSection] = useState(null);
  const [error, setError] = useState('');

  useEffect(() => {
    const loadSession = async () => {
      try {
        const sessionId = location.state?.sessionId;
        if (!sessionId) {
          navigate('/');
          return;
        }

        const sessionDoc = await getDoc(doc(db, 'sessions', sessionId));
        if (!sessionDoc.exists()) {
          throw new Error('Session not found');
        }

        const data = sessionDoc.data();
        setSessionData({
          id: sessionId,
          ...data,
          currentHtml: data.drafts[data.drafts.length - 1].html
        });
      } catch (err) {
        console.error('Session loading error:', err);
        setError('Failed to load session: ' + err.message);
      }
    };

    loadSession();
  }, [location.state, navigate]);

  const handleSectionClick = (section) => {
    setSelectedSection(section);
  };

  const handleHtmlUpdate = (newHtml, sectionId) => {
    if (!sessionData) return;

    setSessionData(prev => ({
      ...prev,
      currentHtml: prev.currentHtml.replace(
        new RegExp(`${sectionId}.*?(?=${sectionId + 1}|$)`, 's'),
        `${sectionId}\n${newHtml}\n`
      )
    }));
  };

  if (error) {
    return <div className="error-container">{error}</div>;
  }

  if (!sessionData) {
    return <div className="loading-container">Loading...</div>;
  }

  return (
    <div className="current-page">
      <div className="content-container">
        <PreviewFrame 
          html={sessionData.currentHtml}
          onSectionClick={handleSectionClick}
        />
        <RecordingSection 
          selectedSection={selectedSection}
          onUpdateHtml={handleHtmlUpdate}
        />
      </div>
      <SessionControls 
        sessionId={sessionData.id}
        html={sessionData.currentHtml}
        sessionName={sessionData.title}
      />
    </div>
  );
};

export default CurrentPage;

