import React, { useState, useEffect } from 'react';
import { useLocation } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { doc, getDoc, updateDoc } from 'firebase/firestore';
import './FinalPage.css';

const FinalPage = () => {
  const location = useLocation();
  const [html, setHtml] = useState('');
  const [error, setError] = useState('');
  const [sessionId, setSessionId] = useState(null);

  useEffect(() => {
    const processHtml = async () => {
      try {
        const id = location.state?.sessionId;
        if (!id) {
          throw new Error('No session ID provided');
        }
        setSessionId(id);

        const sessionDoc = await getDoc(doc(db, 'sessions', id));
        if (!sessionDoc.exists()) {
          throw new Error('Session not found');
        }

        const sessionData = sessionDoc.data();
        let processedHtml = sessionData.drafts[sessionData.drafts.length - 1].html;

        // Remove section markers
        processedHtml = processedHtml.replace(/SECTION\d+/g, '');

        // Replace SVG placeholders with actual SVGs
        if (sessionData.svgs) {
          sessionData.svgs.forEach((svg, index) => {
            processedHtml = processedHtml.replace(`[SVG${index + 1}]`, svg);
          });
        }

        setHtml(processedHtml);

        // Save processed HTML
        await updateDoc(doc(db, 'sessions', id), {
          finalBuild: processedHtml,
          processedAt: new Date().toISOString()
        });

      } catch (err) {
        console.error('Error processing HTML:', err);
        setError(err.message);
      }
    };

    processHtml();
  }, [location.state]);

  const handleDownload = () => {
    const blob = new Blob([html], { type: 'text/html' });
    const url = URL.createObjectURL(blob);
    const a = document.createElement('a');
    a.href = url;
    a.download = 'processed-page.html';
    document.body.appendChild(a);
    a.click();
    URL.revokeObjectURL(url);
    document.body.removeChild(a);
  };

  if (error) {
    return <div className="error-message">{error}</div>;
  }

  return (
    <div className="final-page">
      <h1>Processed HTML</h1>
      <div className="actions">
        <button onClick={handleDownload} className="download-btn">
          Download HTML
        </button>
      </div>
      <div className="preview">
        <iframe
          srcDoc={html}
          title="Processed HTML Preview"
          className="preview-frame"
        />
      </div>
    </div>
  );
};

export default FinalPage;

