import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { db } from '../services/firebase-config';
import { collection, getDocs, orderBy, query } from 'firebase/firestore';
import './SessionsPage.css';

const SessionsPage = () => {
  const navigate = useNavigate();
  const [sessions, setSessions] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState('');

  useEffect(() => {
    const loadSessions = async () => {
      try {
        const sessionsQuery = query(
          collection(db, 'sessions'),
          orderBy('timestamp', 'desc')
        );
        
        const snapshot = await getDocs(sessionsQuery);
        const sessionData = snapshot.docs.map(doc => ({
          id: doc.id,
          ...doc.data()
        }));
        
        setSessions(sessionData);
      } catch (err) {
        console.error('Error loading sessions:', err);
        setError('Failed to load sessions: ' + err.message);
      } finally {
        setLoading(false);
      }
    };

    loadSessions();
  }, []);

  const handleEdit = (sessionId) => {
    navigate('/current', { state: { sessionId } });
  };

  const handleDownload = (session) => {
    const finalHtml = session.finalBuild || session.drafts[session.drafts.length - 1].html;
    const blob = new Blob([finalHtml], { type: 'text/html' });
    const url = window.URL.createObjectURL(blob);
    const a = document.createElement('a');
    a.href = url;
    a.download = `${session.title || 'page'}.html`;
    document.body.appendChild(a);
    a.click();
    window.URL.revokeObjectURL(url);
    document.body.removeChild(a);
  };

  if (loading) {
    return <div className="loading-message">Loading sessions...</div>;
  }

  if (error) {
    return <div className="error-message">{error}</div>;
  }

  return (
    <div className="sessions-page">
      <h1>HTML Sessions</h1>
      <div className="sessions-table">
        <table>
          <thead>
            <tr>
              <th>Title</th>
              <th>Last Edited</th>
              <th>Preview</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {sessions.map(session => (
              <tr key={session.id}>
                <td>{session.title}</td>
                <td>
                  {new Date(session.timestamp).toLocaleDateString()} 
                  {new Date(session.timestamp).toLocaleTimeString()}
                </td>
                <td>
                  <button className="preview-btn" disabled>Preview</button>
                </td>
                <td className="actions">
                  <button
                    className="edit-btn"
                    onClick={() => handleEdit(session.id)}
                  >
                    Edit
                  </button>
                  <button
                    className="download-btn"
                    onClick={() => handleDownload(session)}
                  >
                    Download
                  </button>
                </td>
              </tr>
            ))}
          </tbody>
        </table>
      </div>
    </div>
  );
};

export default SessionsPage;

